@@ -55,8 +55,16 @@ get_colors <- function(...) {
 #' @importFrom raster unstack
 #' @keywords internal
 build_map_data <- function(...) {
+  
    
     mapdata <- list(...)
+   
+    # Conver sf to sp
+    sf_idx <- which(unlist(lapply(mapdata, 
+                                  function(x) inherits(x, c("sf", "sfc")))))
+    for(i in sf_idx){
+      mapdata[[i]] <- sf::as_Spatial(mapdata[[i]])
+    }
 
     # Deal with qmaps
     qmap_idx <- na.omit(match(lapply(mapdata, class), "qmap"))[1]
@@ -79,16 +87,6 @@ build_map_data <- function(...) {
     name <- name[!name %in% "list"]
     names(mapdata) <- name
     mapdata <- unlist(mapdata)
-    name <- names(mapdata)
-    name <- gsub("^list\\(.*\\)\\.", "", name)
-    name <- gsub("\\)[0-9]$", "", name)
-    name <- gsub("\\)$", "", name)
-    name <- gsub("^list\\(", "", name)
-    name <- unlist(strsplit(name, ","))
-    name <- unlist(strsplit(name, "="))
-    name <- gsub(" ", "", name)
-    name <- unique(name)
-    names(mapdata) <- name
     return(mapdata)
 }
 
@@ -176,3 +174,4 @@ make_jpw <- function(file, bbx, width) {
     writeLines(as.character(upper_left_y), con)
     close(con)
 } 
+
